@@ -179,21 +179,21 @@ class Picture(models.Model):
         get_latest_by = 'date_added'
         verbose_name = _('picture')
         verbose_name_plural = _('pictures')
-        unique_together = (('slug', 'album'),)
 
     @property
     def EXIF(self):
         image_file = open(self.original_image.path, 'rb')
         try:
-            data = EXIF.process_file(image_file)
+            return EXIF.process_file(image_file)
         except Exception, e:
             # TODO: log exception
             try:
-                data = EXIF.process_file(image_file, details=False)
+                return EXIF.process_file(image_file, details=False)
             except Exception, e:
-                pass # TODO: log exception
-        image_file.close()
-        return data
+                # TODO: log exception
+                return {}
+        finally:
+            image_file.close()
 
     def save(self, *args, **kwargs):
         super(Picture, self).save(*args, **kwargs)
@@ -209,8 +209,7 @@ class Picture(models.Model):
     @models.permalink
     def get_absolute_url(self):
         return ('galeria-picture', None, {
-            'year' : str(self.date_added.year),
-            'month': str(self.date_added.month).zfill(2),
-            'day'  : str(self.date_added.day).zfill(2),
+            'album_slug' : str(self.album.slug),
+            'pk' : str(self.pk),
             'slug' : str(self.slug)
         })
